# Multiple Imputation Standard Errors

::: survey_kit.statistics.multiple_imputation.mi_ses_from_function
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
        
::: survey_kit.statistics.multiple_imputation.MultipleImputation
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
